Split class

Constructors

Split(String contractAddress, String providerUrl, [String? signerPrivateKey])

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

contractType() Future
contractURI() Future
contractVersion() Future
DEFAULT_ADMIN_ROLE() Future
distribute([String? token]) Future
getRoleAdmin(String role) Future
getRoleMember(String role, BigInt index) Future
getRoleMemberCount(String role) Future
grantRole(String role, String account) Future
hasRole(String role, String account) Future
isTrustedForwarder(String forwarder) Future
multicall(List<String> data) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
payee(BigInt index) Future
payeeCount() Future
release(String account, [String? token]) Future
released(String account, [String? token]) Future
renounceRole(String role, String account) Future
revokeRole(String role, String account) Future
setContractURI(String uri) Future
shares(String account) Future
supportsInterface(String interfaceId) Future
toString() String
A string representation of this object.
inherited
totalReleased([String? token]) Future
totalShares() Future

Operators

operator ==(Object other) bool
The equality operator.
inherited