ERC20 class
Constructors
Properties
- contract ↔ ContractERC20
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
provider
↔ Provider<
_ProviderImpl> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
signer
↔ Signer<
_SignerImpl> ? -
getter/setter pair
Methods
-
allowance(
String owner, String spender) → Future< BigInt> -
approve(
String spender, BigInt amount) → Future< TransactionResponse> -
balanceOf(
String address) → Future< BigInt> -
burn(
BigInt amount) → Future< TransactionResponse> -
decimals(
) → Future< int> -
getPastTotalSupply(
BigInt blockNumber) → Future< BigInt> -
mint(
String recipient, BigInt amount) → Future< TransactionResponse> -
name(
) → Future< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → Future< TransactionResponse> -
symbol(
) → Future< String> -
toString(
) → String -
A string representation of this object.
inherited
-
totalSupply(
) → Future< BigInt> -
transfer(
String recipient, BigInt amount) → Future< TransactionResponse> -
transferFrom(
String sender, String recipient, BigInt amount) → Future< TransactionResponse> -
unpause(
) → Future< TransactionResponse>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited