Token class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allowance(String owner, String spender)
→ Future
-
-
approve(String spender, BigInt amount)
→ Future
-
-
balanceOf(String account)
→ Future
-
-
burn(BigInt amount)
→ Future
-
-
burnFrom(String account, BigInt amount)
→ Future
-
-
checkpoints(String accounts, int pos)
→ Future
-
-
claim(String receiver, BigInt quantity, String currency, BigInt pricePerToken, Map<String, dynamic> allowlistProof, String data)
→ Future
-
-
claimCondition()
→ Future
-
-
contractType()
→ Future
-
-
contractURI()
→ Future
-
-
contractVersion()
→ Future
-
-
decimals()
→ Future
-
-
decreaseAllowance(String spender, BigInt subtractedValue)
→ Future
-
-
DEFAULT_ADMIN_ROLE()
→ Future
-
-
delegate(String delegatee)
→ Future
-
-
delegateBySig(String delegatee, BigInt nonce, BigInt expiry, int v, String r, String s)
→ Future
-
-
delegates(String account)
→ Future
-
-
DOMAIN_SEPARATOR()
→ Future
-
-
encryptDecrypt(String data, String key)
→ Future
-
-
getActiveClaimConditionId()
→ Future
-
-
getClaimConditionId(BigInt conditionId)
→ Future
-
-
getPastTotalSupply(BigInt blockNumber)
→ Future
-
-
getPastVotes(String account, BigInt blockNumber)
→ Future
-
-
getPlatformFeeInfo()
→ Future
-
-
getRoleAdmin(String role)
→ Future
-
-
getRoleMember(String role, BigInt index)
→ Future
-
-
getRoleMemberCount(String role)
→ Future
-
-
getSupplyClaimedByWallet(BigInt conditionId, String claimer)
→ Future
-
-
getVotes(String account)
→ Future
-
-
grantRole(String role, String account)
→ Future
-
-
hasRole(String role, String account)
→ Future
-
-
hasRoleWithSwitch(String role, String account)
→ Future
-
-
increaseAllowance(String spender, BigInt addedValue)
→ Future
-
-
isTrustedForwarder(String forwarder)
→ Future
-
-
maxTotalSupply()
→ Future
-
-
multicall(List data)
→ Future
-
-
name()
→ Future
-
-
nonces(String owner)
→ Future
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
numCheckpoints(String account)
→ Future
-
-
permit(String owner, String spender, BigInt value, BigInt deadline, int v, String r, String s)
→ Future
-
-
primarySaleRecipient()
→ Future
-
-
renounceRole(String role, String account)
→ Future
-
-
revokeRole(String role, String account)
→ Future
-
-
setClaimConditions(List conditions, bool resetClaimEligibility)
→ Future
-
-
setContractURI(String uri)
→ Future
-
-
setMaxTotalSupply(BigInt maxTotalSupply)
→ Future
-
-
setPlatformFeeInfo(String platformFeeRecipient, BigInt platformFeeBps)
→ Future
-
-
setPrimarySaleRecipient(String saleRecipient)
→ Future
-
-
symbol()
→ Future
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
totalSupply()
→ Future
-
-
transfer(String to, BigInt amount)
→ Future
-
-
transferFrom(String from, String to, BigInt amount)
→ Future
-
-
verifyClaim(BigInt conditionId, String claimer, BigInt quantity, String currency, BigInt pricePerToken, Map<String, dynamic> allowlistProof)
→ Future
-